@@ -22,7 +22,8 @@ class FlashMiddleware(object):
     request object.
     """
     
-    def get_context_from_request(self, request):
+    @staticmethod
+    def get_context_from_request(request):
         """Gets the FlashScope object from the request and returns it. If this
         object couldn't be found, the method returns a brand new FlashScope
         object.
@@ -35,7 +36,8 @@ class FlashMiddleware(object):
                     repr(context))
         return context
     
-    def get_context_from_session(self, request):
+    @staticmethod
+    def get_context_from_session(request):
         """Gets the FlashScope object from the session and increments the
         age of flash-scoped objects. If this object couldn't be found, the
         method returns a brand new FlashScope object.
@@ -46,14 +48,16 @@ class FlashMiddleware(object):
             context.increment_age()
         return context
     
-    def process_request(self, request):
+    @staticmethod
+    def process_request(request):
         "Called by Django when a request arrives."
-        request.flash = self.get_context_from_session(request)
+        request.flash = FlashMiddleware.get_context_from_session(request)
     
-    def process_response(self, request, response):
+    @staticmethod
+    def process_response(request, response):
         "Called by Django when a response is sent."
         if hasattr(request, 'session'):
-            context = self.get_context_from_request(request)
+            context = FlashMiddleware.get_context_from_request(request)
             if not context.is_current_empty():
                 request.session['flash'] = context
         return response
